@@ -2,7 +2,7 @@
 
 """mesh_sync provides entry point main()."""
 
-__version__ = "1.0.6"
+__version__ = "1.0.7"
 
 import argparse
 import base64
@@ -163,52 +163,95 @@ def main():
     parser = argparse.ArgumentParser(description='Downloads the latest version of the update files from the github repo')
     parser.add_argument('-p', help='Project ID', required=False)
 
+    # Add argument called update that requires no arguments
+    parser.add_argument('-u', help='Update files', action='store_true')
+
     args = parser.parse_args()
     project_id = args.p
     print("Project ID: %s" % project_id)
+    # Check if user wrote the -u argument
+    if args.u:
+        print(">> Updating files...")
+        # Check if UPDATE_FILE exists in the root of the folder
+        if os.path.exists('UPDATE_FILE'):
+            print(">> Found UPDATE_FILE")
+            # Check if 'project' is in the UPDATE_FILE
+            with open('UPDATE_FILE', 'r') as f:
+                content = f.read()
+                if 'project' in content:
+                    # Get the project name using regex
+                    project_name = re.search(r'project:(.*)', content).group(1)
+                    print(">> Project name: %s" % project_name)
 
-    try:
-        token = input("Enter your GitHub token: ")
+                    token = input("Enter your GitHub token: ")
 
-        print(">> Executing mesh_sync version %s." % __version__)
-        if check_if_dot_git_exists():
-            print(">> Found .git folder, checking for updates...")
-            git_url = find_git_url()
-            if git_url is not None:
-                print(">> Found git url: %s" % git_url)
-                get_update_file(auth_token=token, repo_url=git_url)
-        else:
+                    git_url_input = project_name.rstrip('/')
 
-            print(">> Could not find .git url")
-            if project_id is None:
-                git_url_input = input("Please enter the [Project ID] that was given to you: ")
-            else:
-                git_url_input = project_id
+                    # Remove spaces from all the sides of the string
+                    git_url_input = git_url_input.strip()
 
-            git_url_input = git_url_input.rstrip('/')
+                    if '/' not in git_url_input:
+                        # Single Project ID given, add prefix 'MeshMonitors-Remote-1/'
+                        git_url_input = f"MeshMonitors-Remote-1/{git_url_input}"
 
-            # Remove spaces from all the sides of the string
-            git_url_input = git_url_input.strip()
+                    if git_url_input is not None:
+                        is_empty = os.listdir(os.getcwd()) == []
+                        if is_empty:
+                            print(">> No files found in the current directory, downloading latest version...")
+                            get_all_files(token,
+                                          f"https://api.github.com/repos/{git_url_input}/git/trees/master?recursive=1",
+                                          git_url_input)
+                        else:
+                            print(">> Found files in the current directory, updating latest version...")
+                            get_update_file(auth_token=token, repo_url=git_url_input)
 
-            if '/' not in git_url_input:
-
-                # Single Project ID given, add prefix 'MeshMonitors-Remote-1/'
-                git_url_input = f"MeshMonitors-Remote-1/{git_url_input}"
-
-            if git_url_input is not None:
-                is_empty = os.listdir(os.getcwd()) == []
-                if is_empty:
-                    print(">> No files found in the current directory, downloading latest version...")
-                    get_all_files(token, f"https://api.github.com/repos/{git_url_input}/git/trees/master?recursive=1",
-                                  git_url_input)
                 else:
-                    print(">> Found files in the current directory, updating latest version...")
-                    get_update_file(auth_token=token, repo_url=git_url_input)
+                    print(">> No project found in the UPDATE_FILE")
+        else:
+            print(">> No UPDATE_FILE found in root of folder")
+    else:
+        try:
+            token = input("Enter your GitHub token: ")
+
+            print(">> Executing mesh_sync version %s." % __version__)
+            if check_if_dot_git_exists():
+                print(">> Found .git folder, checking for updates...")
+                git_url = find_git_url()
+                if git_url is not None:
+                    print(">> Found git url: %s" % git_url)
+                    get_update_file(auth_token=token, repo_url=git_url)
             else:
-                print("Please enter a valid git url. Aborting...")
-                sys.exit(0)
-    except Exception as e:
-        print("Error: %s" % e)
-        sys.exit(0)
-    finally:
-        print(">> Done.")
+
+                print(">> Could not find .git url")
+                if project_id is None:
+                    git_url_input = input("Please enter the [Project ID] that was given to you: ")
+                else:
+                    git_url_input = project_id
+
+                git_url_input = git_url_input.rstrip('/')
+
+                # Remove spaces from all the sides of the string
+                git_url_input = git_url_input.strip()
+
+                if '/' not in git_url_input:
+
+                    # Single Project ID given, add prefix 'MeshMonitors-Remote-1/'
+                    git_url_input = f"MeshMonitors-Remote-1/{git_url_input}"
+
+                if git_url_input is not None:
+                    is_empty = os.listdir(os.getcwd()) == []
+                    if is_empty:
+                        print(">> No files found in the current directory, downloading latest version...")
+                        get_all_files(token, f"https://api.github.com/repos/{git_url_input}/git/trees/master?recursive=1",
+                                      git_url_input)
+                    else:
+                        print(">> Found files in the current directory, updating latest version...")
+                        get_update_file(auth_token=token, repo_url=git_url_input)
+                else:
+                    print("Please enter a valid git url. Aborting...")
+                    sys.exit(0)
+        except Exception as e:
+            print("Error: %s" % e)
+            sys.exit(0)
+        finally:
+            print(">> Done.")
